@@ -14,6 +14,7 @@
 # limitations under the License.
 
 import time
+from qubell.api.globals import ZONE_NAME, DEFAULT_ENV_NAME
 from qubell.api.tools import lazyproperty
 
 __author__ = "Vasyl Khomenko"
@@ -29,8 +30,6 @@ from qubell.api.private import exceptions
 from qubell.api.private.common import QubellEntityList, Entity
 from qubell.api.provider.router import ROUTER as router
 
-from qubell.api.private.service import COBALT_SECURE_STORE_TYPE
-
 class Environment(Entity):
 
     def __init__(self, organization, id):
@@ -44,7 +43,6 @@ class Environment(Entity):
         self.properties = []
         self.providers = []
 
-
     @lazyproperty
     def zoneId(self):
         return self.json()['backend']
@@ -69,42 +67,37 @@ class Environment(Entity):
         return resp[key] or False
 
     @staticmethod
-    def new(organization, name, zone=None, default=False):
+    def new(organization, name, zone_id=None, default=False):
         log.info("Creating environment: %s" % name)
-        if not zone:
-            zone = organization.zone.zoneId
+        if not zone_id:
+            zone_id = organization.zone.zoneId
         data = {'isDefault': default,
                 'name': name,
-                'backend': zone,
+                'backend': zone_id,
                 'organizationId': organization.organizationId}
         resp = router.post_organization_environment(org_id=organization.organizationId, data=json.dumps(data)).json()
         return Environment(organization, id=resp['id'])
 
-    def restore(self, config):
+    def restore(self, config, clean=False, timeout=10):
         config = copy.deepcopy(config)
-        self.clean()
+        if clean:
+            self.clean()
         for marker in config.pop('markers', []):
             self.add_marker(marker)
         for policy in config.pop('policies', []):
             self.add_policy(policy)
         for property in config.pop('properties', []):
             self.add_property(**property)
-        if config.get('provider', None):
-            provider = config.pop('provider')
+        if config.get('cloudAccount', None) or config.get('provider', None):
+            provider = config.get('cloudAccount') or config.get('provider')
             prov = self.organization.get_provider(id=provider.pop('id', None), name=provider.pop('name'))
             self.add_provider(prov)
         for service in config.pop('services', []):
             type=service.pop('type', None)
             serv = self.organization.get_service(id=service.pop('id', None), name=service.pop('name'))
             self.add_service(serv)
-
-            if type == COBALT_SECURE_STORE_TYPE:
-                # TODO: We do not need to regenerate key every time. Find better way.
-                myenv = self.organization.get_environment(self.environmentId)
-                myenv.add_policy(
-                    {"action": "provisionVms",
-                     "parameter": "publicKeyId",
-                     "value": serv.regenerate()['id']})
+        for service in self.services:
+            service.ready()
 
     def json(self):
         return router.get_environment(org_id=self.organizationId, env_id=self.environmentId).json()
@@ -126,15 +119,26 @@ class Environment(Entity):
     _put_environment = lambda self, data: router.put_environment(org_id=self.organizationId, env_id=self.environmentId, data=data)
 
     def add_service(self, service):
-        if not service in self.services:
-            time.sleep(3) # TODO: Need to wait until strategy comes up
+        resp = None
+        if service not in self.services:
+            time.sleep(3)  # TODO: Need to wait until strategy comes up
             data = self.json()
             data['serviceIds'].append(service.instanceId)
             data['services'].append(service.json())
-
             resp = self._put_environment(data=json.dumps(data))
-            return resp.json()
-        return None
+
+        if service.is_secure_vault:
+            user_data = service.userData
+            if 'defaultKey' in user_data:
+                key = user_data['defaultKey']
+            else:
+                key = service.regenerate()['id']
+
+            self.add_policy(
+                {"action": "provisionVms",
+                 "parameter": "publicKeyId",
+                 "value": key})
+        return resp.json() if resp else None
 
     def remove_service(self, service):
         data = self.json()
@@ -216,3 +220,23 @@ class Environment(Entity):
 
 class EnvironmentList(QubellEntityList):
     base_clz = Environment
+    @property
+    def default(self):
+        """
+            Returns environment marked as default.
+            When Zone is set marked default makes no sense, special env with proper Zone is returned.
+        """
+        if ZONE_NAME:
+            log.info("Getting or creating default environment for zone with name '{0}'".format(DEFAULT_ENV_NAME()))
+            zone_id = self.organization.zones[ZONE_NAME].id
+            return self.organization.get_or_create_environment(name=DEFAULT_ENV_NAME(), zone=zone_id)
+
+        def_envs = [env_j["id"] for env_j in self.json() if env_j["isDefault"] == True]
+
+        if len(def_envs)>1:
+            log.warning('Found more than one default environment. Picking last.')
+            return self[def_envs[-1]]
+        elif len(def_envs) == 1:
+            return self[def_envs[0]]
+        raise exceptions.NotFoundError('Unable to get default environment')
+
