@@ -14,6 +14,7 @@
 # limitations under the License.
 import logging as log
 import warnings
+import copy
 
 import simplejson as json
 from qubell.api.private import exceptions
@@ -72,7 +73,9 @@ class QubellPlatform(object):
         return OrganizationList(list_json_method=self.list_organizations_json)
 
     def create_organization(self, name):
-        return Organization.new(name)
+        org = Organization.new(name)
+        org.ready()
+        return org
 
     def get_organization(self, id=None, name=None):
         log.info("Picking organization: %s" % (id or name))
@@ -91,12 +94,13 @@ class QubellPlatform(object):
 
     organization = get_or_create_organization
 
-    def restore(self, config):
+    def restore(self, config, clean=False, timeout=10):
+        config = copy.deepcopy(config)
         for org in config.pop('organizations', []):
             restored_org = self.get_or_create_organization(id=org.get('id'), name=org.get('name'))
-            restored_org.restore(org)
+            restored_org.restore(org, clean, timeout)
 
-    @deprecated
-    def get_context(self):
+    @property
+    def info(self):
         return self.auth
 
