@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
 __author__ = "Anton Panasenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
@@ -27,7 +26,7 @@ import re
 
 from functools import wraps
 
-from qubell.api.private.manifest import Manifest
+from qubell.api.globals import *
 from qubell.api.private.service import system_application_types, COBALT_SECURE_STORE_TYPE, WORKFLOW_SERVICE_TYPE
 
 import logging
@@ -35,6 +34,7 @@ import types
 
 logging.getLogger("requests.packages.urllib3.connectionpool").setLevel(logging.WARN)
 
+
 def format_as_api(data):
     """
     Accepts {'default':{},}
@@ -130,9 +130,9 @@ def environment(envdata):
 
         methods = [method
                    for _, method in clazz.__dict__.items()
-                   if isinstance(method, types.FunctionType) and method.func_name.startswith("test") ]
+                   if isinstance(method, types.FunctionType) and method.func_name.startswith("test")]
         for env in params:
-            if env['name'] != 'default':
+            if env['name'] != DEFAULT_ENV_NAME():
                 env['name'] += '_for_%s' % clazz.__name__   # Each test class should have it's own set of envs.
 
         for method in methods:
@@ -156,7 +156,7 @@ def instance(byApplication):
             elif "_testMethodName" in self.__dict__ and len(self._testMethodName.split(separator)) > 1:
                 env = self._testMethodName.split(separator)[1]
             else:
-                env = "default"
+                env = DEFAULT_ENV_NAME()
             return env
 
         @wraps(func)
@@ -186,17 +186,17 @@ class BaseTestCase(unittest.TestCase):
 
         addon = {"provider": {"name": cls.parameters['provider_name']},
                  "services":
-                    [{"name": "Default credentials service"},
-                     {"name": "Default workflow service"}
+                    [{"name": DEFAULT_CREDENTIAL_SERVICE()},
+                     {"name": DEFAULT_WORKFLOW_SERVICE()}
                     ]}
 
-        envs = cls.environments or [{"name": "default"},]
+        envs = cls.environments or [{"name": DEFAULT_ENV_NAME()},]
 
         for env in envs:
-            env.update(addon) # Add provider, keystore, workflow to every env.
+            env.update(addon)  # Add provider, keystore, workflow to every env.
 
-        servs = [{"type": COBALT_SECURE_STORE_TYPE, "name": 'Default credentials service'},
-                 {"type": WORKFLOW_SERVICE_TYPE, "name": 'Default workflow service', "parameters": {'configuration.policies': '{}'}}]
+        servs = [{"type": COBALT_SECURE_STORE_TYPE, "name": DEFAULT_CREDENTIAL_SERVICE()},
+                 {"type": WORKFLOW_SERVICE_TYPE, "name": DEFAULT_WORKFLOW_SERVICE()}]
 
         return {
             "organization": {"name": organization},
@@ -238,15 +238,19 @@ class BaseTestCase(unittest.TestCase):
         """
         cls.sandbox = SandBox(cls.platform, cls.environment(organization))
         cls.organization = cls.sandbox.make()
-        cls.instances = cls.organization.instances
+        cls.regular_instances = []
+        cls.service_instances = []
+
 
         def launch_in_env(app, env):
             environment = cls.organization.environments[env['name']]
             application = cls.organization.applications[app['name']]
             parameters = app.get('parameters', {})
+            settings = app.get('settings', {})
             instance = cls.organization.create_instance(application=application,
                                                         environment=environment,
-                                                        parameters=parameters)
+                                                        parameters=parameters,
+                                                        **settings)
             if app.get('add_as_service', False):
                 environment.add_service(instance)
             cls.sandbox.sandbox["instances"].append({
@@ -266,7 +270,6 @@ class BaseTestCase(unittest.TestCase):
                     assert False, "Instance %s is not ready after %s minutes and stop on timeout" % (instance.instanceId, timeout)
 
         # launch service instances first
-        cls.service_instances = []
         for app in cls.sandbox['applications']:
             for env in cls.sandbox['environments']:
                 if app.get('launch', True) and app.get('add_as_service', False):
@@ -274,12 +277,13 @@ class BaseTestCase(unittest.TestCase):
         check_instances(cls.service_instances)
 
         # then launch non-service instances
-        cls.regular_instances = []
         for app in cls.sandbox['applications']:
             for env in cls.sandbox['environments']:
                 if app.get('launch', True) and not app.get('add_as_service', False):
                     cls.regular_instances.append(launch_in_env(app, env))
         check_instances(cls.regular_instances)
+        
+        cls.instances = cls.service_instances + cls.regular_instances
 
     @classmethod
     def clean(cls, timeout=10):
